/*
  DL6LAU Web Control (de DL6MHW)
  using WebServer Example from Arduino 1.05  
 
 Circuit:
 * Ethernet shield attached to pins 10, 11, 12, 13
 * Digital Output D0 - D8
 * Analog inputs attached to pins A0 through A2 (optional)
 
 created 8 Nov 2013
 by Michael Hoeding (DL6MHW) dl6mhw@darc.de
 */

#include <SPI.h>
#include <Ethernet.h>

// Enter a MAC address and IP address for your controller below.
// The IP address will be dependent on your local network:
byte mac[] = { 0x90, 0xA2, 0xDA, 0x0D, 0xDE, 0x6E };
IPAddress ip(192,168,1,73);
int cnt=1;
boolean debug = false;
//boolean debug = true;

// Initialize the Ethernet server library
// with the IP address and port you want to use 
// (port 80 is default for HTTP):
EthernetServer server(80);
int start=0; //2 für test 0 für hot
int active=1;
char dir[]="no";
int dindex=-1;
char status[12]="a.........";

void setup() {
  //allo leds HIGH
  if (debug) start=2;
  for (int i=start; i<9; i++) {
    pinMode(i, OUTPUT);     
    digitalWrite(i, HIGH); 
  }  
  digitalWrite(0, LOW); 
  
 //Open serial communications and wait for port to open:
  if (debug) Serial.begin(9600);
  // start the Ethernet connection and the server:
  Ethernet.begin(mac,ip);
  server.begin();
  if (debug) {
    Serial.print("server is at ");
    Serial.println(Ethernet.localIP());
  }  
}

void setActive(int nextAntenna) {
  digitalWrite(active, HIGH); 
  status[active]='x';
  digitalWrite(0, HIGH); 
  status[0]='x';
  active=nextAntenna;   
  digitalWrite(active, LOW); 
  status[active]='a';
}  

void htmlHeader(EthernetClient client) {
          // send a standard http response header
          client.println("HTTP/1.1 200 OK");
          client.println("Content-Type: text/html");
          client.println("Connection: close");  // the connection will be closed after completion of the response
	  client.println("Refresh: 60");  // refresh the page automatically every 5 sec
          client.println();
          client.println("<!DOCTYPE HTML>");
          client.println("<html><head><title>DL6LAU -Arduino Control</title>");
          client.println("<style type=\"text/css\">");
          client.println("<!--");
          client.println("input{font-size:28px; height:60px;width:60px;}");
          client.println("div{font-size:18px; text-align:center;color:#ffe;}");
          client.println(".a {background-color:#f00;}");
          client.println(".g {background-color:#0d0;width:60px; height:25px;}");
          client.println(".w {background-color:#aaa;width:60px; height:25px;}");
          client.println(".mini {font-size:8px; color:#eee;width:160px}");
          client.println("-->");
          client.println("</style>");
          client.println("</head>");
          client.println("<body>");
}  

void loop() {
  // listen for incoming clients
  EthernetClient client = server.available();
  if (client) {
    if (debug)  Serial.println("new client");
    // an http request ends with a blank line
    boolean currentLineIsBlank = true;
    dindex=-1;
    while (client.connected()) {
      if (client.available()) {
        char c =  client.read();
        if (dindex > -1 && dindex<2) { 
           dir[dindex] = c;
           dindex++;
        }   
        if (c == '=' && dindex<0) dindex=0;
  
        if (debug) Serial.print(c);
        if (debug) Serial.println(dir);
        
        //Str[StrIndex] = c;
        //if (StrIndex<100) StrIndex++;
        //Serial.write(c);
        
        // if you've gotten to the end of the line (received a newline
        // character) and the line is blank, the http request has ended,
        // so you can send a reply
        if (c == '\n' && currentLineIsBlank) {
          htmlHeader(client);
          if (dir[0]=='N' && dir[1]=='W') setActive(8);                    
          if (dir[0]=='W' && dir[1]=='+') setActive(7);                    
          if (dir[0]=='S' && dir[1]=='W') setActive(6);                    
          if (dir[0]=='S' && dir[1]=='+') setActive(5);                    
          if (dir[0]=='S' && dir[1]=='E') setActive(4);                    
          if (dir[0]=='E' && dir[1]=='+') setActive(3);                    
          if (dir[0]=='N' && dir[1]=='E') setActive(2);                    
          if (dir[0]=='N' && dir[1]=='+') setActive(1);                    
          if (dir[0]=='L') {
             digitalWrite(0, LOW); 
             status[0]='a'; 
             status[active]='x'; 
          }   

          client.println("<form action=\"index.html\" method=\"GET\"><table>");
          client.println("<tr>");
          client.print("<td><input type=\"submit\" name=\"direction\" value=\"NW\" class=\"");
          client.print(status[8]);
          client.println("\"></td>");
          client.print("<td><input type=\"submit\" name=\"direction\" value=\"N \" class=\"");
          client.print(status[1]);
          client.println("\"></td>");
          client.print("<td><input type=\"submit\" name=\"direction\" value=\"NE\" class=\"");
          client.print(status[2]);
          client.println("\"></td>");
          client.println("</tr>");

          client.println("<tr>");
          client.print("<td><input type=\"submit\" name=\"direction\" value=\"W \" class=\"");
          client.print(status[7]);
          client.println("\"></td>");
          client.print("<td><input type=\"submit\" name=\"direction\" value=\"Loc\" class=\"");
          client.print(status[0]);
          client.println("\"></td>");
          client.print("<td><input type=\"submit\" name=\"direction\" value=\"E \" class=\"");
          client.print(status[3]);
          client.println("\"></td>");
          client.println("</tr>");

          client.println("<tr>");
          client.print("<td><input type=\"submit\" name=\"direction\" value=\"SW\" class=\"");
          client.print(status[6]);
          client.println("\"></td>");
          client.print("<td><input type=\"submit\" name=\"direction\" value=\"S \" class=\"");
          client.print(status[5]);
          client.println("\"></td>");
          client.print("<td><input type=\"submit\" name=\"direction\" value=\"SE\" class=\"");
          client.print(status[4]);
          client.println("\"></td>");
          client.println("</tr>");

          client.println("<tr>");
        for (int aC = 0; aC < 3; aC++) {
          long val = analogRead(aC);
          val=(100*val)/1024;
          if (val>50) client.print("<td><div class=\"g\">");
          else client.print("<td><div class=\"w\">");
          client.print(val);
          client.println(" %</div></td>");
        }
          client.println("</tr>");
         
          client.println("</table></form>");
          client.println("<div class=\"mini\">DL6MHW 8NOV13</div></body></html>");
          break;
        }
        if (c == '\n') {
          // you're starting a new line
          currentLineIsBlank = true;
        } 
        else if (c != '\r') {
          // you've gotten a character on the current line
          currentLineIsBlank = false;
        }
      }
    }
    // give the web browser time to receive the data
    delay(1);
    // close the connection:
    client.stop();
    //Serial.println("client disonnected");
  }
}

